/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */
import { SMouseEvent } from "@persagy-web/base";
import { SEquipItem } from "@persagy-web/big"
import { SGraphItem, STextItem, SGraphCircleItem } from "@persagy-web/graph/lib";
import { SColor, SFont, SPoint, SPainter } from "@persagy-web/draw/lib";
import { SCircleItem } from "./SCircleItem"
/**
 * 拓扑图派生设备类
 *
 *  @author  韩耀龙 <han_yao_long@163.com>
 */

export class EquipItem extends SEquipItem {
    StatusPoint: SCircleItem | null = null;
    constructor(parent: SGraphItem | null) {
        super(parent);
    }
    // 设置设备名称
    setEquipName() {
        const item = new STextItem(this);
        item.text = this.data.properties.localName;
        // item.strokeColor = new SColor('#6b7086');
        item.color = new SColor('#6b7086')
        item.font = new SFont("sans-serif", 16);
        item.isTransform = false;
        // item.font = new SFont("sans-serif", 16);
        item.moveTo(-this.width / 2, this.height / 2);
        this.setStatusPoint(item)
    }

    /**
     * 设置状态点
     *
     * @param parent 父类
     */
    setStatusPoint(parent: STextItem | null) {
        const item = new SCircleItem(parent);
        const h = parent ? parent.height : 0
        item.localtion = new SPoint(0, 0);
        item.radius = 4;
        item.fillColor = new SColor('#de6466');
        item.strokeColor = new SColor('#de6466')
        item.moveTo(-item.radius * 2, h)
        this.StatusPoint = item;
    }

    /**
     * 设置状态远点颜色
     *
     * @param val 颜色字符
     */
    setStatusPointColor(val: string) {
        if (!this.StatusPoint) return;
        this.StatusPoint.fillColor = new SColor(val);
        this.StatusPoint.strokeColor = new SColor(val);
    }

    /**
     * 获取信息点数组
     */
    getMsgList(): any {
        return this.textItemList
    }

    onMouseMove(event: SMouseEvent): boolean {
        const scene = this.scene;
        if (null != scene) {
            if (scene.hoverItem == null || scene.hoverItem !== this) {
                if (scene.hoverItem != null) {
                    scene.hoverItem.onMouseLeave(event);
                }
                this.onMouseEnter(event);
                scene.hoverItem = this;
            }
        }
        return true
    }
    /**
     * 鼠标进入事件
     *''
     * @param event   保存事件参数
     * @return 是否处理事件
     */
    onMouseEnter(event: SMouseEvent): boolean {
        this.$emit("onMouseEnter");
        return false;
    }

    /**
     * 鼠标离开事件
     *
     * @param event   保存事件参数
     * @return 是否处理事件
     */
    onMouseLeave(event: SMouseEvent): boolean {
        this.$emit("onMouseLeave");
        return false;
    }
    // 显示图片阴影
    _showImgShadow = false;
    get showImgShadow(): boolean {
        return this._showImgShadow
    }
    set showImgShadow(v: boolean) {
        this._showImgShadow = v;
        this.update()
    }
    onDraw(painter: SPainter): void {
        if (this.showImgShadow) {
            painter.shadow.shadowBlur = 20;
            painter.shadow.shadowColor = new SColor(`#000000`);
            painter.shadow.shadowOffsetX = 10;
            painter.shadow.shadowOffsetY = 10;
        } else {
            painter.shadow.shadowColor = SColor.Transparent;
        }
    }
}