/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

import { SGraphItem, SLineStyle } from "@persagy-web/graph/lib";
import { SPainter, SColor, SFont, SPoint } from "@persagy-web/draw/lib";
import { SCircleCornerPolylineItem } from "@persagy-web/big"
export class Pipe extends SGraphItem {
    pointList: SGraphItem | null;
    // 底部默认的管道
    pipe_default: SCircleCornerPolylineItem
    // 管道上部的流动像素
    pipe_flow: SCircleCornerPolylineItem

    // 设置弧度
    private _radius: number = 5;
    get radius(): number {
        return this.pipe_default.radius;
    }
    set radius(v: number) {
        if (v === this._radius) {
            return;
        }
        // 设置弧度
        this.pipe_default.radius = v;
        this.pipe_flow.radius = v;
    }

    /** 圆角半径是否需要转像素值 */
    private _radiusIsPx: boolean = false;
    get radiusIsPx(): boolean {
        return this.pipe_default.radiusIsPx;
    }
    set radiusIsPx(v: boolean) {
        if (v === this._radiusIsPx) {
            return;
        }
        // 设置弧度
        this.pipe_default.radiusIsPx = v;
        this.pipe_flow.radiusIsPx = v;
    }

    get strokeColor(): SColor {
        return this.pipe_default.strokeColor
    }
    set strokeColor(v: SColor) {
        // 设置弧度
        this.pipe_default.strokeColor = v;
    }
    get data(): any {
        return this.pipe_default.data
    }
    set data(v: any) {
        // 设置弧度
        this.pipe_default.data = v;
    }

    //    内管道颜色
    get flowStrokeColor(): SColor {
        return this.pipe_flow.strokeColor
    }
    set flowStrokeColor(v: SColor) {
        // 设置弧度
        this.pipe_flow.strokeColor = v;
    }

    get fillColor(): SColor {
        return this.pipe_default.fillColor;
    }
    set fillColor(v: SColor) {
        this.pipe_default.fillColor = v;
    }
    // 内管道填充颜色
    get flowFillColor(): SColor {
        return this.pipe_flow.strokeColor
    }
    set flowFillColor(v: SColor) {
        // 设置弧度
        this.pipe_flow.strokeColor = v;
    }

    get lineWidth(): number {
        return this.pipe_default.lineWidth;
    }
    set lineWidth(v: number) {
        this.pipe_default.lineWidth = v;
        this.pipe_flow.lineWidth = this.pipe_default.lineWidth * this._flowWithScale
    }
    // 内外管道比
    _flowWithScale: number = 0.6;
    set flowWithScale(val: number) {
        this._flowWithScale = val;
        this.pipe_flow.lineWidth = this.pipe_default.lineWidth * this._flowWithScale
    }
    get flowWithScale(): number {
        return this._flowWithScale
    }

    // 线样式
    get lineStyle(): SLineStyle {
        return this.pipe_default.lineStyle;
    }
    set lineStyle(v: SLineStyle) {
        this.pipe_default.lineStyle = v;
    }
    // 内管道线样式
    get flowLineStyle(): SLineStyle {
        return this.pipe_flow.lineStyle;
    }
    set flowLineStyle(v: SLineStyle) {
        this.pipe_flow.lineStyle = v;
    }
    // 是否显示滚动
    _showScroll = true
    get showScroll(): boolean {
        return this._showScroll;
    }
    set showScroll(v: boolean) {
        this._showScroll = v;
        if(v){
            this._flowScroll()
        }else{
            if(this._setInteveal){
                clearInterval(this._setInteveal);
                this._setInteveal = null;
            }
        }
    }
    _setInteveal :any = null;

    constructor(parent: SGraphItem | null, pointList: any) {
        super(parent)
        this.pointList = pointList;
        // 底部默认的管道
        this.pipe_default = new SCircleCornerPolylineItem(this, pointList)
        // 管道上部的流动像素
        this.pipe_flow = new SCircleCornerPolylineItem(this, pointList)

        this.flowFillColor = new SColor('#ffffff');    //内管颜色
        this.flowStrokeColor = new SColor('#ffffff'); // 内管颜色
        this.flowLineStyle = SLineStyle.Dashed;  //线型
        this.pipe_default.widthIsPx = true; //显示像素宽
        this.pipe_flow.widthIsPx = true; //像素宽
        this.showScroll = true; //是否滚动
    }
    _flowScroll(){
        this._setInteveal =  setInterval(()=>{
            this.update()
        },60)
    }
    onDraw(painter: SPainter): void{
        if(this.showScroll){
            painter.pen.dashOffset = new Date().getTime() / 50 % 40;
        }
    }

}